<?php
/**
 *  Description of GepPautareuniaoLogic
 *
 *  @package Logic.
 *
 *  @author  samuelleite
 */
class GepPautareuniaoLogic {


    /**
     * Insere Pauta da Reuniao.
     *
     * @param integer  $nrpautareuniao Numero da Pauta de reuniao.
     * @param integer  $nrorg          Numero da organizacao.
     * @param integer  $nrreuniao      Numero da reunicao.
     * @param integer  $nrordenapauta  Numero da ordenacao.
     * @param string   $dsgrupopauta   Grupo da Pauta.
     * @param string   $dstitulopauta  Titulo da Pauta.
     * @param string   $txpauta        Texto da Pauta.
     * @param string   $dsobservpauta  Obsevacao da Pauta.
     * @param dateTime $dtinclusao     Data de inclusao.
     * @param string   $cdoperinclusao Codigo do operador inclusao.
     * @param integer  $nrorginclusao  Numero da organizacao inclusora.
     * @param dateTime $dtultatu       Data de atualizacao.
     * @param integer  $cdoperultatu   Codigo do operador ultatu.
     * @param string   $nrorgultatu    Numero da organizacao ultatu.
     *
     * @return boolean
     */
    public static function incluiPauta(
        $nrpautareuniao, $nrorg, $nrreuniao,
        $nrordenapauta, $dsgrupopauta, $dstitulopauta,
        $txpauta, $dsobservpauta, dateTime $dtinclusao,
        $cdoperinclusao, $nrorginclusao, dateTime $dtultatu,
        $cdoperultatu, $nrorgultatu
    ){
        $dados = GepPautareuniaoEntity::incluiPauta(
            $nrpautareuniao, $nrorg, $nrreuniao,
            $nrordenapauta, $dsgrupopauta, $dstitulopauta,
            $txpauta, $dsobservpauta, $dtinclusao,
            $cdoperinclusao, $nrorginclusao, $dtultatu,
            $cdoperultatu, $nrorgultatu
        );
        return $dados;
    }


    /**
     * Consulta o maior valor de ordenacao entre os textos da pauta de reuniao.
     *
     * @param integer $nrorg   Numero da Organizacao.
     * @param integer $reuniao Numero da reuniao.
     *
     * @return multitype:|boolean
     */
    public static function proximoValorOrdenacaoPauta($nrorg, $reuniao){
        $maior = GepPautareuniaoEntity::consultaMaiorValorOrdenacaoPauta($nrorg, $reuniao);

        if ($maior === null) {
            return $maior;
        } else {
            return ++$maior;
        }
    }


    /**
     * Retorna dados de uma pauta de reuniao
     *
     * @param integer $reuniao Numero da reuniao.
     * @param integer $nrorg   Numero da organizacao.
     *
     * @return Ambigous <<type>, multitype:, mixed>|boolean
     */
    public static function consultaPautasByReuniao($reuniao ,$nrorg) {
        $pautareuniao = GepPautareuniaoEntity::consultaPautasByReuniao($reuniao, $nrorg);
        return $pautareuniao;
    }


    public static function novoCodigoGepPautaReuniao($nrorg){
        $codigo = GepPautaReuniaoEntity::retornaProxNumeroPautareuniao($nrorg);
        return $codigo;
    }


    /**
    * Exclui Pautas da Reuniao.
    *
    * @param integer $nrreuniao Numero da reuniao.
    * @param integer $nrorg     Numero da Organizacao.
    *
    * @return void
    */
    public static function excluiPautasPorReuniao($nrreuniao, $nrorg){
        GepPautareuniaoEntity::excluiPautasPorReuniao($nrreuniao, $nrorg);
    }


}